@@ -4,14 +4,14 @@ package jp.ac.takushoku_u.cs;
 * DisagreementMatrixSizeException饹2ĤΥޥȥꥯФӤ黻Ԥݡ
 * 2ĤΥޥȥꥯΥפʤ
 * ⤷ϱ黻ԤʤƱΤǤ뤳Ȥ򼨤˥ޤ
-* @version 1.1
+* @version 1.2
 * @author  ͵(Kasajima Hiroshi)
 */
 /*
-* ǽ 2004ǯ0927
+* ǽ 2004ǯ1209
 */
 
-public class DisagreementMatrixSizeException extends ArithmeticMatrixException{
+public class DisagreementMatrixSizeException extends DisagreementSizeException{
 
 /**
 * åʤ DisagreementMatrixSizeException ۤޤ
