@@ -2,11 +2,11 @@ package jp.ac.takushoku_u.cs;
 
 /**
 * IRSAnalysis饹IRSʬϤԤΥ饹Ǥ
-* @version 1.1.1
+* @version 1.1.2
 * @author  ͵(Kasajima Hiroshi)
 */
 /*
-* ǽ 2004ǯ1211
+* ǽ 2005ǯ0118
 */
 public class IRSAnalysis{
 
@@ -71,6 +71,26 @@ public class IRSAnalysis{
 		setThreshold(threshold);
 	}
 	
+/**
+* 򸵤ʬоݤΥޥȥꥯꤷޤ
+* ͤϥǥեͤꤵޤ
+* @param baseMatrix ʬоݤΥޥȥꥯ
+*/
+	public IRSAnalysis(BooleanMatrix baseMatrix){
+		setMatrix(baseMatrix.toArithmeticMatrix());
+		setThreshold(IRSANALYSIS_THRESHOLD);
+	}
+	
+/**
+* 򸵤ʬоݤΥޥȥꥯȤͤꤷޤ
+* @param baseMatrix ʬоݤΥޥȥꥯ
+* @param threshold ꤹ뤷
+*/
+	public IRSAnalysis(BooleanMatrix baseMatrix, double threshold){
+		setMatrix(baseMatrix.toArithmeticMatrix());
+		setThreshold(threshold);
+	}
+	
 /**
 * ʬоݤȤꤵƤޥȥꥯ֤ޤ
 * @return ʬоݤΥޥȥꥯ
@@ -229,11 +249,6 @@ public class IRSAnalysis{
 									(irsMatrix.getCell(order[k], searchCol) == IRSANALYSIS_SEQUENCE_FALSE)){
 										counter = counter + 1;		//ʤϥ󥿡䤹
 								}
-								
-								//ޤƱʿξ
-								//else if(matrix.getColAverage(order[k]) == matrix.getColAverage(searchRow)){
-									//counter = counter + 1;
-								//}
 							}
 
 							//Ƥ¾λޤ褫餽ǤؽϢʤϻޤ
