@@ -3,14 +3,14 @@ package jp.ac.takushoku_u.cs;
 /**
 * NegativeMatrixSizeException饹Υĥޥȥꥯ
 * 褦ȤȤ򼨤˥ޤ
-* @version 1.1
+* @version 1.2
 * @author  ͵(Kasajima Hiroshi)
 */
 /*
-* ǽ 2004ǯ1112
+* ǽ 2004ǯ1209
 */
 
-public class NegativeMatrixSizeException extends MatrixException{
+public class NegativeMatrixSizeException extends NegativeSizeException{
 
 /**
 * åʤ NegativeMatrixSizeException ۤޤ
